==> merchant-base-0.5.56-RELEASE-sources.jar: com/rocogz/merchant/request/goods/BaseGoodsReq.java <==
package com.rocogz.merchant.request.goods;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.rocogz.merchant.request.base.PageReq;
import lombok.Data;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author djt
 * @date 2021/7/20
 */
@Data
public class BaseGoodsReq extends PageReq {

    private String name;

    private String code;
    //合作客户产品状态
    private String status;
    //发放主体产品状态
    private String issuingBodyGoodsStatus;
    //产品性质
    private String goodsNature;

    private String belongIdentify;

    private List<String> includeCodes;

    private List<String> excludeGoodsTypes;

    private List<String> includeGoodsTypes;

    /**
     * 发放主体
     */
    private String issuingBodyCode;


    public Map<String,Object> toMap(){
        Map<String, Object> params = new HashMap<>(8);
        if (StringUtils.isNotBlank(this.name)){
            params.put("name", "%"+this.name+"%");
        }
        if (StringUtils.isNotBlank(this.code)){
            params.put("code", "%"+this.code+"%");
        }
        if (StringUtils.isNotBlank(this.status)){
            params.put("status", this.status);
        }
        if (StringUtils.isNotBlank(this.issuingBodyGoodsStatus)){
            params.put("issuingBodyGoodsStatus", this.issuingBodyGoodsStatus);
        }
        if (CollectionUtils.isNotEmpty(this.includeCodes)){
            params.put("includeCodes", this.includeCodes);
        }

        if (StringUtils.isNotBlank(this.belongIdentify)){
            params.put("belongIdentify", this.belongIdentify);
        }
        if(this.excludeGoodsTypes != null && this.excludeGoodsTypes.size() > 0){
            params.put("excludeGoodsTypes",this.excludeGoodsTypes);
        }
        if(this.includeGoodsTypes != null && this.includeGoodsTypes.size() > 0){
            params.put("includeGoodsTypes",this.includeGoodsTypes);
        }
        if (StringUtils.isNotBlank(this.issuingBodyCode)){
            params.put("issuingBodyCode", this.issuingBodyCode);
        }

        if(StringUtils.isNotBlank(this.goodsNature)){
            params.put("goodsNature", this.goodsNature);
        }
        return params;
    }

}

==> merchant-base-0.5.59-RELEASE-sources.jar: com/rocogz/merchant/request/goods/BaseGoodsReq.java <==
package com.rocogz.merchant.request.goods;

import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.rocogz.merchant.request.base.PageReq;
import lombok.Data;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author djt
 * @date 2021/7/20
 */
@Data
public class BaseGoodsReq extends PageReq {

    private String name;

    private String code;
    //合作客户产品状态
    private String status;
    //发放主体产品状态
    private String issuingBodyGoodsStatus;
    //产品性质
    private String goodsNature;

    private String belongIdentify;

    private List<String> includeCodes;

    private List<String> excludeGoodsTypes;

    private List<String> includeGoodsTypes;

    /**
     * 发放主体
     */
    private String issuingBodyCode;

    /**
     * 业务类型：主体中业务类型
     *
     * 主体 如果 该业务类型仅可发放已添加的专用产品：Y 再传递这个值
     */
    private String businessTypeCode;




    public Map<String,Object> toMap(){
        Map<String, Object> params = new HashMap<>(8);
        if (StringUtils.isNotBlank(this.name)){
            params.put("name", "%"+this.name+"%");
        }
        if (StringUtils.isNotBlank(this.code)){
            params.put("code", "%"+this.code+"%");
        }
        if (StringUtils.isNotBlank(this.status)){
            params.put("status", this.status);
        }
        if (StringUtils.isNotBlank(this.issuingBodyGoodsStatus)){
            params.put("issuingBodyGoodsStatus", this.issuingBodyGoodsStatus);
        }
        if (CollectionUtils.isNotEmpty(this.includeCodes)){
            params.put("includeCodes", this.includeCodes);
        }

        if (StringUtils.isNotBlank(this.belongIdentify)){
            params.put("belongIdentify", this.belongIdentify);
        }
        if(this.excludeGoodsTypes != null && this.excludeGoodsTypes.size() > 0){
            params.put("excludeGoodsTypes",this.excludeGoodsTypes);
        }
        if(this.includeGoodsTypes != null && this.includeGoodsTypes.size() > 0){
            params.put("includeGoodsTypes",this.includeGoodsTypes);
        }
        if (StringUtils.isNotBlank(this.issuingBodyCode)){
            params.put("issuingBodyCode", this.issuingBodyCode);
        }

        if(StringUtils.isNotBlank(this.goodsNature)){
            params.put("goodsNature", this.goodsNature);
        }

        if(StringUtils.isNotBlank(this.businessTypeCode)){
            params.put("businessTypeCode", this.businessTypeCode);
        }

        return params;
    }

}
